# Generated by Django 4.2.3 on 2023-07-18 06:55

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Check',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('ticket_url', models.URLField(blank=True, null=True, verbose_name='Ticket URL')),
                ('ticket_print_url', models.URLField(blank=True, null=True, verbose_name='Ticket URL for print')),
                ('check_number', models.CharField(blank=True, max_length=255, null=True, verbose_name='Check number')),
                ('date_time', models.CharField(blank=True, max_length=255, null=True, verbose_name='Check datetime')),
                ('cash_box', models.JSONField(blank=True, null=True, verbose_name='Cashbox')),
                ('check_order_number', models.BigIntegerField(default=0, verbose_name='Check order number')),
                ('shift_number', models.BigIntegerField(default=0, verbose_name='Shift number')),
                ('employee_name', models.CharField(blank=True, max_length=255, null=True, verbose_name='Employee name')),
            ],
            options={
                'verbose_name': 'Check',
                'verbose_name_plural': 'Checks',
            },
        ),
        migrations.CreateModel(
            name='WebKassaAccount',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('password', models.CharField(max_length=300)),
                ('cashbox_unique_number', models.CharField(max_length=255)),
                ('is_encrypted', models.BooleanField(default=False)),
                ('token', models.CharField(default='', max_length=100)),
            ],
            options={
                'verbose_name': 'Webkassa account',
                'verbose_name_plural': 'Webkassa accounts',
            },
        ),
        migrations.CreateModel(
            name='WebkassaErrorLog',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('code', models.CharField(max_length=10)),
                ('text', models.TextField()),
                ('check_obj', models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
                                                related_name='error_logs', to='webkassa.check', verbose_name='Check')),
            ],
            options={
                'verbose_name': 'Webkassa error',
                'verbose_name_plural': 'Webkassa errors',
            },
        ),
    ]
